@@ -3,9 +3,9 @@
 
 import numpy as np
 import tensorflow as tf
-from my_bert.backend import keras, K
-from my_bert.backend import sequence_masking
-from my_bert.backend import recompute_grad
+from bert4keras.backend import keras, K
+from bert4keras.backend import sequence_masking
+from bert4keras.backend import recompute_grad
 from keras import initializers, activations
 from keras.layers import *
 
